<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Quiz;
use App\Models\QuizRecord;
use App\Models\ResultSummary;
use App\Models\ActivityMaster;
use App\Models\User;
use DB;
use Log;
class QuizController extends Controller {

    /**
     * Get all students
     */
    public function get_all() {
        try {
            $quiz_records = QuizRecord::get() ;
            return response()->json([ 'quiz_records' => $quiz_records], 200);
        } catch ( \Exception $e ) {
            Log::error( $e );
            return response()->json( ['message' => $e->getmessage()], 500 );
        }

    }

    public function getActivityMaster() {
        try {
            $data = ActivityMaster::get() ;
            return response()->json( $data, 200);
        } catch ( \Exception $e ) {
            return response()->json( ['message' => $e->getmessage()], 500 );
        }

    }

    public function getActivityMasterById($id) {
        try {
            $data = ActivityMaster::Where('activity_id',$id)->first();
            return response()->json( $data, 200);
        } catch ( \Exception $e ) {
            return response()->json( ['message' => $e->getmessage()], 500 );
        }

    }


    // /**
    //  * Get all students count
    //  */
    // public function get_count() {
    //     try {
    //         $quiz_counts = QuizRecord::count() ;
    //         return response()->json([ 'quiz_counts' => $quiz_counts], 200);
    //     } catch ( \Exception $e ) {
    //         Log::error( $e );
    //         return response()->json( ['message' => $e->getmessage()], 500 );
    //     }
    // }

    /**
     * Get student by gender
     */
    public function search( Request $request ) {

        $search = $request->search;

        // $Students =  Quiz::where('name','LIKE',"%{$search}%")
        // ->orWhere('rollno', 'LIKE',"%{$search}%")
        // ->orWhere('branch', 'LIKE',"%{$search}%")
        // ->orWhere('phno', 'LIKE',"%{$search}%")
        // ->orWhere('username', 'LIKE',"%{$search}%")
        // ->get();

       // return response()->json( $Quiz );
    }


    public function get_players_count() {
        try {
            $players_count = User::count() ;
            return response()->json([ 'players_count' => $players_count], 200);
        } catch ( \Exception $e ) {
            Log::error( $e );
            return response()->json( ['message' => $e->getmessage()], 500 );
        }
    }

    public function get_quiz_count() {

        try {
            $quiz_count = User::count() ;
            return response()->json([ 'quiz_count' => $quiz_count], 200);
        } catch ( \Exception $e ) {
            Log::error( $e );
            return response()->json( ['message' => $e->getmessage()], 500 );
        }
    }

    public function get_avg_time() {
        try {
            $QuizRecord = QuizRecord::get();
            $QuizRecordCount = QuizRecord::count();
            $duration = 0;
            $avg_time = 0;
            foreach ($QuizRecord as $item) {
                $duration += $item->duration;
            }
            $avg_time = $duration/$QuizRecordCount;
            return response()->json([ 'avg_time' => $avg_time], 200);
        } catch ( \Exception $e ) {
            Log::error( $e );
            return response()->json( ['message' => $e->getmessage()], 500 );
        }
        
        return response()->json( $players_count );
    }

    public function help_needed_students() { 
        $help_needed_students = [
            0 => [
                'name' => 'Dilhara',
                'marks' => 15
            ],
            1 => [
                'name' => 'Chamath',
                'marks' => 23
            ],
        ];
        return response()->json( $help_needed_students );
    }

    public function difficult_quiz() { 
        $difficult_quiz = [
            0 => [
                'quiz' => 'What is this?',
            ],
            1 => [
                'quiz' => 'When it happened?',
            ],
        ];
        return response()->json( $difficult_quiz );
    }

    public function getCompletedStudents($id) { 
        $count = DB::table('tbl_student')
        ->leftJoin('activities', 'tbl_student.student_id', '=', 'activities.student_id')
        ->select(DB::raw('count(activities.student_id)*100/count(tbl_student.student_id) as count'))
        ->Where('activities.activity_id',$id)
        ->first();
        return response()->json( ['count'=>$count] );
    }
    
    public function getRankings($id) {
        $ranking = DB::table('tbl_result_summary')
        ->select(DB::raw('count(student_id) as count, grade'))
        ->groupBy('grade')
        ->Where('activity_id',$id)
        ->get();
        return response()->json( $ranking );
    }

    
    public function getLowStudents($id) {
        $students = ResultSummary::with('info')
        ->Where('marks' ,'<=', '30')
        ->Where('activity_id',$id)
        ->get();
        return response()->json( ['students' => $students] );
    }

    public function getDiffQuiz( $id ) {
        try {
            $quiz = DB::table('tbl_question')
                    ->join('tbl_result', function($join)
                         {
                             $join->on('tbl_question.question_id', '=', 'tbl_result.question_id');
                             $join->on('tbl_result.user_answer', '!=', 'tbl_result.right_answer');
                         })
                         ->select('tbl_question.*')
                   ->Where('activity_id', $id)->distinct()->get();
            return response()->json([ 'quiz' => $quiz], 200);
        } catch ( \Exception $e ) {
            return response()->json( ['message' => $e->getmessage()], 500 );
        }
    }
}
