<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Students;
use App\Models\Prediction;
use App\Models\ResultSummary;

use Illuminate\Support\Facades\DB;

class StudentsController extends Controller {

    /**
     * Get all students
     */
    public function get_all() {
        try {
            $students = Students::all();
            return response()->json([ 'students' => $students], 200);
        } catch ( \Exception $e ) {
            //Log::error( $e );
            return response()->json( ['message' => $e->getmessage()], 500 );
        }
    }

    /**
     * Get student by id
     */
    public function get_by_id( $id ) {
        return response()->json( Students::where('student_id' , $id)->first());
    }

    /**
     * Get all students count
     */
    public function get_count() {
        return response()->json( Students::count() );
    }

    /**
     * Get student by gender
     */
    public function search( Request $request ) {

        $search = $request->search;

        $Students =  Students::where('name','LIKE',"%{$search}%")
        ->orWhere('rollno', 'LIKE',"%{$search}%")
        ->orWhere('branch', 'LIKE',"%{$search}%")
        ->orWhere('phno', 'LIKE',"%{$search}%")
        ->orWhere('username', 'LIKE',"%{$search}%")
        ->get();

        return response()->json( $Students );
    }

    public function get_attendance($sId) {
        $counts = DB::select(DB::raw('select count(attendanceid) as count from attendance where MONTH(date) = month(CURRENT_DATE) and student_id = '.$sId));
        return response()->json($counts);
    }

    public function get_works($id) {
        $works = ResultSummary::Where('student_id',$id)->orderByDesc('added_date')->first();
        return response()->json( $works );
    }
    

    public function get_last_performamce($sId) {
        // $performance = [
        //     0 => [
        //         'subject' => 'English',
        //         'marks' => 80
        //     ],
        //     1 => [
        //         'subject' => 'ICT',
        //         'marks' => 90
        //     ],
        // ];
        $performance = DB::table('activities')
        ->select(DB::raw('count(marks) as marks, type as subject'))
        ->groupBy('type')
        ->Where('student_id',$sId)
        ->get();
        return response()->json( $performance );
    }

    public function getPredictedData( $id ) {
        return response()->json( ['result' => Prediction::where('student_id' , $id)->get()]);
    }

}
